<?php
/**
 * ElkArte Ajax Chat
 *
 * @author  wintstar
 * @license BSD http://opensource.org/licenses/BSD-3-Clause
 * @license Bluimp's AJAX Chat is released under a Modified MIT License (MIT) https://raw.githubusercontent.com/Frug/AJAX-Chat/master/chat/license.txt
 *
 * @version 1.0.1
 */

if (!defined('ELK'))
	die('No access...');

/**
 * Chat administration controller.
 * This class allows to modify chat settings for the forum.
 */
class ManageTalk_Controller extends Action_Controller
{
	/**
	 * chat settings forms
	 *
	 * @var _chatMainSettingsForm
	 */
	protected $_talkMainSettingsForm;

	/**
	 * ChatEntry()
	 *
	 * Traffic cop, checks permissions
	 * calls the appropriate sub-function
	 *
	 */
	public function action_index()
	{
		// The entrance point for all 'talk' actions.
		global $context, $txt;

		// Admins only
		isAllowedTo('admin_forum');

		// Language and template stuff, the usual.
		loadLanguage('Talk');
		loadTemplate('Talk');

		// Subaction array ... function to call
		$subActions = array(
			'main' => array($this, 'action_MainSettings_display'),
			'info' => array($this, 'action_InfoSettings_display'),
		);

		// Get ready for some action
		$action = new Action('manage_talk');

		// Default page title is good.
		$context['page_title'] = $txt['attachments_avatars'];

		// Get the subAction, call integrate_sa_manage_talk
		$subAction = $action->initialize($subActions, 'main');
		$context['sub_action'] = $subAction;

		// This uses admin tabs - as it should!
		$context[$context['admin_menu_name']]['tab_data'] = array(
			'title' => $txt['talk_index'],
			'help' => $txt['talk_help'],
			'description' => $txt['talk_description_' . $subAction],
		);

		// Finally go to where we want to go
		$action->dispatch($subAction);
	}

	/**
	 * Show the main form
	 */
	public function action_MainSettings_display()
	{
		global $txt, $context, $scripturl;

		// We're working with them settings here.
		require_once(SUBSDIR . '/SettingsForm.class.php');

		// Initialize the form
		$this->_initTalkMainSettingsForm();
		$config_vars = $this->_talkMainSettingsForm->settings();

		// Saving?
		if (isset($_GET['save']))
		{
			// You can save, maybe
			checkSession();
			Settings_Form::save_db($config_vars);
			redirectexit('action=admin;area=talk;sa=main');
		}

		// Setup the title and template.
		$context['page_title'] = $txt['talk_main_settings'];
		$context['sub_template'] = 'show_settings';
		$context['post_url'] = $scripturl . '?action=admin;area=talk;sa=main;save';
		$context['settings_title'] = $txt['talk_main_settings'];

		Settings_Form::prepare_db($config_vars);
	}

	/**
	 * Prepare the main form
	 * @return type
	 */
	private function _initTalkMainSettingsForm()
	{
		// Instantiate the form
		$this->_talkMainSettingsForm = new Settings_Form();

		// Initialize settings
		$config_vars = $this->_talk_mainsettings();

		return $this->_talkMainSettingsForm->settings($config_vars);
	}

	/**
	 * Show the info form
	 */
	public function action_InfoSettings_display()
	{
		global $txt, $context, $scripturl;

		global $txt, $context, $scripturl;

		loadTemplate('TalkHelp');
		loadCSSFile('chat.css');

		// Setup the title and template.
		$context['page_title'] = $txt['talkhelp_index'];
		$context['sub_template'] = 'TalkHelp';
	}

	/**
	 * Load the main options for the addon
	 */
	private function _talk_mainsettings()
	{
		global $txt;

		$config_vars = array(
			array('check', 'talk_chatEnable'),
			'',
			array('check', 'talk_chatPage'),
			array('check', 'talk_aboveIndex'),
			array('check', 'talk_belowIndex', 'subtext' => $txt['talk_info']),
			'',
			array('check', 'talk_buttonInside'),
			array('check', 'talk_userInside'),
			);

		return $config_vars;
	}

	/**
	 * Initialize attachmentForm.
	 *
	 * - Retrieve and return the administration settings for Ajax Chat settings
	 */
	private function _initTalkSettingsForm()
	{
		// Instantiate the form
		$this->_talkSettingsForm = new Settings_Form();

		// Initialize settings
		$config_vars = $this->_talk_settings();

		return $this->_talkSettingsForm->settings($config_vars);
	}

	private function _talk_infosettings()
	{
		global $txt;

		$config_vars = array(
		);

		return $config_vars;
	}
}